#!/bin/bash

# -e  Exit immediately if a command exits with a non-zero status.
# -u  Treat unset variables as an error when substituting.
set -eu

START=`date +%s`

echo "😎 Generate stats"

docker cp histoiredunpied:/var/log/nginx/access.log access.log
goaccess access.log \
  -o public/stats.html \
  --real-os --ignore-crawlers --agent-list --hour-spec=min \
  --log-format=COMBINED \
  --anonymize-ip \
  --exclude-ip=192.168.1.254 --ignore-referer=176.174.163.152:443 \
  --html-prefs='{"theme":"brillant","perPage":20,"layout":"vertical","showTables":false,"visitors":{"plot":{"chartType":"bar"}}}' \
  --enable-panel=VISITORS --enable-panel=OS --enable-panel=BROWSERS --enable-panel=VISIT_TIMES --enable-panel=REFERRING_SITES \
  --ignore-panel=REQUESTS --ignore-panel=REQUESTS_STATIC --ignore-panel=NOT_FOUND --ignore-panel=HOSTS --ignore-panel=VIRTUAL_HOSTS --ignore-panel=REFERRERS --ignore-panel=KEYPHRASES --ignore-panel=STATUS_CODES --ignore-panel=REMOTE_USER --ignore-panel=GEO_LOCATION
rm access.log
docker cp public/stats.html histoiredunpied:/usr/share/nginx/html


END=`date +%s`
echo "✨ Done in $((END-START))s"
